/**

## ABOUT ##

Author: Daniel Sim (a.k.a. foxhead128; Argent Zerda)
Version: 0.3.2

Description:
fhPlayer is a JavaScript library for building a kludgy HTML5 audio player.
Java and Flash can be used as fallbacks in the event that a browser does not
support the audio codecs you use.

## LICENSING TERMS ##

Copyright (c) 2012 foxhead128

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

## USAGE ##

First, download the button player from the XSPF Web Music Player, which can be
found at the following URL:
https://sourceforge.net/projects/musicplayer/files/musicplayer/button_player-0.1/

Extract the .ZIP archive to some folder on your website. Inside, there should be
a file named musicplayer.swf. Once you've done that, basic usage of fhPlayer
is as follows (Note that there are not supposed to be any new lines!):

<script type="text/javascript" src="fhplayer.js"></script>
<script type="text/javascript">
window.onload = function() { fhPlayer("fhPlayer"); }
</script>
<div id="fhPlayer"<br/>swf="/path/to/musicplayer.swf"
playlist="/path/to/1st-audio-file;name-of-1st-audio-file|
/path/to/2nd-audio-file;name-of-2nd-audio-file|
/path/to/3rd-audio-file;name-of-3rd-audio-file [etc.]"></div>

## KNOWN ISSUES ##

* In Firefox, the controls may not show up at all. In the event that this happens,
  I've implemented a basic fallback mode using HTML <input> tags.
  
* The trackbar won't work for audio formats that are not natively-supported.

* Browsers that do not support native Ogg Vorbis audio will need the Java plugin.

* Browsers that do not support native MP3 audio will need the Flash plugin.

* There is no fallback mode for AAC, WAV, and WebM, except for attempting to load
  the file in an iframe and relying on whatever plugins the browser may have installed.

**/

var userAgent = navigator.userAgent.toLowerCase();
window.fhPlayer_IsTrackBarMoving = false;
var checkAudio = document.createElement('audio');
if (checkAudio.canPlayType) {
    var canPlayMp3 = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/mpeg');
    var canPlayWebM = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/webm');
    var canPlayOgg = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/ogg; codecs="vorbis"');
    var canPlayWav = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/wave');
    if (!canPlayWav) {
        var canPlayWav = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/wav');
    }
    var canPlayAac = !!checkAudio.canPlayType && "" != checkAudio.canPlayType('audio/aac');
}
else {
    var canPlayMp3 = false;
    var canPlayWebM = false;
    var canPlayOgg = false;
    var canPlayWav = false;
    var canPlayAac = false;
}

function loadFallback(fhPlayerDiv, url) {
    document.getElementById(fhPlayerDiv + '_AudioIFrame').setAttribute('src',url);
}

function fhPlayer_PrimeTrackBar(fhPlayerDiv) {
    if (document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime < 1) {
        document.getElementById(fhPlayerDiv + '_Slider').value = 0;
    }
}

function fhPlayer_DurationChange(fhPlayerDiv) {
    document.getElementById(fhPlayerDiv + '_Slider').max = document.getElementById(fhPlayerDiv + '_AudioPlayer').duration;
    zero = "";
    if (Math.ceil(document.getElementById(fhPlayerDiv + '_AudioPlayer').duration%60) < 10) {
        zero = "0";
    }
    document.getElementById(fhPlayerDiv + '_TimeBox').innerHTML = "/" + Math.floor(document.getElementById(fhPlayerDiv + '_AudioPlayer').duration/60) + ":" + zero + Math.ceil(document.getElementById(fhPlayerDiv + '_AudioPlayer').duration%60);
}

function fhPlayer_UpdateProgress(fhPlayerDiv) {
    if ((document.getElementById(fhPlayerDiv + '_Slider').value - document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime > 1) || (document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime - document.getElementById(fhPlayerDiv + '_Slider').value > 1)) {
        document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime = document.getElementById(fhPlayerDiv + '_Slider').value;
    }
    else {
        document.getElementById(fhPlayerDiv + '_Slider').value = document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime;
    }
    zero = "";
    if (Math.ceil(document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime%60) < 10) {
        zero = "0";
    }
    document.getElementById(fhPlayerDiv + '_CurrentTimeBox').innerHTML = Math.floor(document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime/60) + ":" + zero + Math.ceil(document.getElementById(fhPlayerDiv + '_AudioPlayer').currentTime%60);
}

function doNothing() {
    return;
}

function removeWhiteSpace(string) {
    return string.replace(/ /g, "").replace(/\n/g, "");
}

function fhPlayer(fhPlayerDiv) {
    if (userAgent.indexOf('firefox') != -1) {
        var html5slider = document.createElement('script');
        html5slider.setAttribute('type', 'text/javascript');
        html5slider.setAttribute('src', 'html5slider.js');
        document.getElementsByTagName('body')[0].appendChild(html5slider);
        delete html5slider;
    }
    var swf = document.getElementById(fhPlayerDiv).getAttribute('swf');
    var audioIFrame = document.createElement('iframe');
    audioIFrame.setAttribute("style", "border: 0; position: fixed; top: 100%; left: 100%; min-width: 0; min-height: 0; width: 0; height: 0; max-width: 0; max-height: 0; margin: 0; border: 0;");
    audioIFrame.setAttribute("id", fhPlayerDiv + "_AudioIFrame");
    audioIFrame.setAttribute("name", fhPlayerDiv + "_AudioIFrame");
    document.getElementById(fhPlayerDiv).appendChild(audioIFrame);
    var nowPlaying = document.createElement('div');
    nowPlaying.setAttribute("id", fhPlayerDiv + "_NowPlaying");
    nowPlaying.setAttribute("style", "font-weight: bold;");
    nowPlaying.innerHTML = "No track selected";
    document.getElementById(fhPlayerDiv).appendChild(nowPlaying);
    var controlsBox = document.createElement('table');
    controlsBox.setAttribute("id", fhPlayerDiv + "_ControlsBox");
    controlsBox.setAttribute("cellpadding", "0");
    controlsBox.setAttribute("cellspacing", "0");
    controlsBox.setAttribute("style", "margin: 0; padding: 0; border: 0; width: 100%;");
    document.getElementById(fhPlayerDiv).appendChild(controlsBox);
    var controlsBoxRow = document.createElement('tr');
    controlsBoxRow.setAttribute('id', fhPlayerDiv + '_ControlsBoxRow');
    document.getElementById(fhPlayerDiv + "_ControlsBox").appendChild(controlsBoxRow);
    var playBox = document.createElement('td');
    playBox.setAttribute('id', fhPlayerDiv + '_PlayBox');
    document.getElementById(fhPlayerDiv + '_ControlsBoxRow').appendChild(playBox);
    var playButton = document.createElement('input');
    playButton.setAttribute("id", fhPlayerDiv + "_PlayButton");
    playButton.setAttribute("type", "button");
    playButton.setAttribute("style", "font-family: sans-serif !important;");
    playButton.setAttribute("onclick", "document.getElementById('" + fhPlayerDiv + "_AudioIFrame').setAttribute('src', 'about:blank'); document.getElementById('" + fhPlayerDiv + "_AudioPlayer').play();");
    playButton.setAttribute("value", ">");
    document.getElementById(fhPlayerDiv + "_PlayBox").appendChild(playButton);
    var pauseBox = document.createElement('td');
    pauseBox.setAttribute('id', fhPlayerDiv + '_PauseBox');
    document.getElementById(fhPlayerDiv + '_ControlsBoxRow').appendChild(pauseBox);
    var pauseButton = document.createElement('input');
    pauseButton.setAttribute("id", fhPlayerDiv + "_PauseButton");
    pauseButton.setAttribute("type", "button");
    pauseButton.setAttribute("style", "font-family: sans-serif !important;");
    pauseButton.setAttribute("onclick", "document.getElementById('" + fhPlayerDiv + "_AudioIFrame').setAttribute('src', 'about:blank'); document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();");
    pauseButton.setAttribute("value", "||");
    document.getElementById(fhPlayerDiv + "_PauseBox").appendChild(pauseButton);
    var audioBox = document.createElement('td');
    audioBox.setAttribute('id', fhPlayerDiv + '_AudioBox');
    audioBox.setAttribute('style', "width: 100%;");
    document.getElementById(fhPlayerDiv + '_ControlsBoxRow').appendChild(audioBox);
    var cTimeBox = document.createElement('td');
    cTimeBox.innerHTML = "0:00";
    cTimeBox.setAttribute('id', fhPlayerDiv + '_CurrentTimeBox');
    document.getElementById(fhPlayerDiv + '_ControlsBoxRow').appendChild(cTimeBox);
    var timeBox = document.createElement('td');
    timeBox.innerHTML = "/0:00";
    timeBox.setAttribute('id', fhPlayerDiv + '_TimeBox');
    document.getElementById(fhPlayerDiv + '_ControlsBoxRow').appendChild(timeBox);
    try {
    var audioPlayer = document.createElement('audio');
    audioPlayer.setAttribute('id', fhPlayerDiv + '_AudioPlayer');
    if (userAgent.indexOf("chrome") == -1 && userAgent.indexOf("firefox") == -1) {
        audioPlayer.setAttribute('controls', 'controls');
    }
    audioPlayer.setAttribute('style', "border: 0; width: 100%;");
    audioPlayer.setAttribute('src', "");
    document.getElementById(fhPlayerDiv + '_AudioBox').appendChild(audioPlayer);
    }
    catch(err) {
       doNothing();
    }
    if (userAgent.indexOf("chrome") != -1 || userAgent.indexOf("firefox") != -1) {
        var slider = document.createElement('input');
        slider.setAttribute('id', fhPlayerDiv + '_Slider');
        slider.setAttribute('type', 'range');
        slider.setAttribute('style', "border: 0; width: 100%;");
        slider.setAttribute('value', "0");
        document.getElementById(fhPlayerDiv + '_AudioBox').appendChild(slider);
        audioPlayer.addEventListener("play", function() { fhPlayer_PrimeTrackBar(fhPlayerDiv); }, false);
        audioPlayer.addEventListener('durationchange', function() { fhPlayer_DurationChange(fhPlayerDiv); }, false);
        slider.setAttribute("onchange", "fhPlayer_UpdateProgress('" + fhPlayerDiv + "');", false);
        audioPlayer.addEventListener("timeupdate", function() { fhPlayer_UpdateProgress(fhPlayerDiv) }, false);
        /**slider.setAttribute("onmouseup", "window.fhPlayer_IsTrackBarMoving = false;", false);**/
    }
    var playlist = document.createElement('div');
    playlist.setAttribute('id', fhPlayerDiv + '_Playlist');
    playlist.setAttribute('style', "margin: 8px; margin-left: 0; margin-right: 0; border: 1px solid ThreeDShadow; padding: 8px; overflow: auto; height: 200px;");
    document.getElementById(fhPlayerDiv + "").appendChild(playlist);
    var playlistString = document.getElementById(fhPlayerDiv).getAttribute('playlist');
    var playlistList = playlistString.split("|");
    var i = 0;
    for(i = 0; i < playlistList.length; i++) {
      var item = playlistList[i].split(";");
      var newPlaylistItem = document.createElement('a');
      newPlaylistItem.setAttribute('href', removeWhiteSpace(item[0]));
      newPlaylistItem.setAttribute('class', "fhPlayer_PlayLink");
      newPlaylistItem.innerHTML = item[1];
      playlist.appendChild(newPlaylistItem);
      var newPlaylistItem2 = document.createElement('a');
      newPlaylistItem2.setAttribute('href', removeWhiteSpace(item[0]));
      newPlaylistItem2.setAttribute('class', "fhPlayer_DownloadLink");
      newPlaylistItem2.setAttribute('style', 'float: right;');
      newPlaylistItem2.innerHTML = "Download";
      playlist.appendChild(newPlaylistItem2);
      var newBreak = document.createElement('br');
      playlist.appendChild(newBreak);
    }
    var foo,i;
    foo=document.getElementById(fhPlayerDiv + "_Playlist").getElementsByTagName("a");
    player="http://www.jcraft.com/jorbis/player/JOrbisPlayer.php?play=";    
    mp3Player=swf + "?&autoplay=true&song_url=";
    for(i=0;i<foo.length;i++){
      if (foo[i].getAttribute('class') == "fhPlayer_PlayLink") {
      try {
      var href=foo[i].href;
      if ((((href.toLowerCase().match(/.ogg$/) || href.toLowerCase().match("/.oga$/")) && canPlayOgg && href.search(/JOrbisPlayer.php/)==-1) || ((href.toLowerCase().match(/.mp3$/) || href.toLowerCase().match("/.m3a$/")) && canPlayMp3)) || ((href.toLowerCase().match(/.m4a$/) || href.toLowerCase().match(/.mp4$/)) && canPlayAac) || ((href.toLowerCase().match(/.webm$/)) && canPlayWebM) || ((href.toLowerCase().match(/.wav$/) || href.toLowerCase().match(/.wave$/)) && canPlayWav)){
        foo[i].href = "javascript:" + "document.getElementById('" + fhPlayerDiv + "_AudioIFrame').setAttribute('src','about:blank');" + "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').setAttribute('src','" + foo[i].href + "');document.getElementById('" + fhPlayerDiv + "_AudioPlayer').load();document.getElementById('" + fhPlayerDiv + "_AudioPlayer').play();";
        if (userAgent.indexOf("firefox") == -1 && userAgent.indexOf("msie") == -1 && userAgent.indexOf("opera") == -1) {
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_NowPlaying').innerHTML='" + foo[i].innerHTML + "';";
        }
        if (userAgent.indexOf('firefox') != -1 || userAgent.indexOf('chrome') != -1) {
          foo[i].setAttribute('onclick', "document.getElementById('" + fhPlayerDiv + "_Slider').value = 0;");
        }
      }
      else if ((href.toLowerCase().match(/.ogg$/) || href.toLowerCase().match(/.oga$/)) && href.toLowerCase().indexOf("JOrbisPlayer.php")==-1) {
        foo[i].target=fhPlayerDiv + "_AudioIFrame";
        if (userAgent.indexOf("firefox") == -1 && userAgent.indexOf("msie") == -1 && userAgent.indexOf("opera") == -1) {
          foo[i].href="javascript:loadFallback('" + fhPlayerDiv + "', '" + player + foo[i].href + "');";
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_NowPlaying').innerHTML='" + foo[i].innerHTML + "';";
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();"
        }
        else {
          foo[i].href = player + foo[i].href;
          foo[i].setAttribute('onclick', "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();");
        }
      }
      else if (href.toLowerCase().match(/.mp3$/) || href.toLowerCase().match(/.m3a$/)) {
        foo[i].target=fhPlayerDiv + "_AudioIFrame";
        if (userAgent.indexOf("firefox") == -1 && userAgent.indexOf("msie") == -1 && userAgent.indexOf("opera") == -1) {
          foo[i].href="javascript:loadFallback('" + fhPlayerDiv + "', '" + mp3Player + foo[i].href + "&');";
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_NowPlaying').innerHTML='" + foo[i].innerHTML + "';";
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();"
          }
        else {
          foo[i].href = mp3Player + foo[i].href;
          foo[i].setAttribute('onclick', "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();");
        }
        }
      else {
        foo[i].href = "javascript:loadFallback('" + fhPlayerDiv + "', '" + foo[i].href + "');";
        if (userAgent.indexOf("firefox") == -1 && userAgent.indexOf("msie") == -1 && userAgent.indexOf("opera") == -1) {
          foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_NowPlaying').innerHTML='" + foo[i].innerHTML + "';";
        }
        foo[i].href = foo[i].href + "document.getElementById('" + fhPlayerDiv + "_AudioPlayer').pause();";
      }
      }
      catch(err) {
        var hello = 'dummy';
      }
      }
    }
    if (userAgent.indexOf("firefox") != -1 || userAgent.indexOf("opera") != -1) {
        document.getElementById(fhPlayerDiv).removeChild(document.getElementById(fhPlayerDiv + '_NowPlaying'));
    }
}

